import pytest
from dbt.tests.adapter.utils.data_types.base_data_type_macro import BaseDataTypeMacro

seeds__expected_csv = """int_col
12345678
""".lstrip()

models__actual_sql = """
select cast('12345678' as {{ type_int() }}) as int_col
"""


class BaseTypeInt(BaseDataTypeMacro):
    @pytest.fixture(scope="class")
    def seeds(self):
        return {"expected.csv": seeds__expected_csv}

    @pytest.fixture(scope="class")
    def models(self):
        return {"actual.sql": self.interpolate_macro_namespace(models__actual_sql, "type_int")}


class TestTypeInt(BaseTypeInt):
    pass



import pytest
import os
from dbt.tests.util import (
    run_dbt,
    get_manifest,
    check_relations_equal,
    check_result_nodes_by_name,
    relation_from_name,
)
from dbt.tests.adapter.basic.files import (
    seeds_base_csv,
    base_ephemeral_sql,
    ephemeral_view_sql,
    ephemeral_table_sql,
    schema_base_yml,
)


class BaseEphemeral:
    @pytest.fixture(scope="class")
    def project_config_update(self):
        return {"name": "ephemeral"}

    @pytest.fixture(scope="class")
    def seeds(self):
        return {"base.csv": seeds_base_csv}

    @pytest.fixture(scope="class")
    def models(self):
        return {
            "ephemeral.sql": base_ephemeral_sql,
            "view_model.sql": ephemeral_view_sql,
            "table_model.sql": ephemeral_table_sql,
            "schema.yml": schema_base_yml,
        }

    def test_ephemeral(self, project):
        # seed command
        results = run_dbt(["seed"])
        assert len(results) == 1
        check_result_nodes_by_name(results, ["base"])

        # run command
        results = run_dbt(["run"])
        assert len(results) == 2
        check_result_nodes_by_name(results, ["view_model", "table_model"])

        # base table rowcount
        relation = relation_from_name(project.adapter, "base")
        result = project.run_sql(f"select count(*) as num_rows from {relation}", fetch="one")
        assert result[0] == 10

        # relations equal
        check_relations_equal(project.adapter, ["base", "view_model", "table_model"])

        # catalog node count
        catalog = run_dbt(["docs", "generate"])
        catalog_path = os.path.join(project.project_root, "target", "catalog.json")
        assert os.path.exists(catalog_path)
        assert len(catalog.nodes) == 3
        assert len(catalog.sources) == 1

        # manifest (not in original)
        manifest = get_manifest(project.project_root)
        assert len(manifest.nodes) == 4
        assert len(manifest.sources) == 1


class TestEphemeral(BaseEphemeral):
    pass



import pytest
from dbt.tests.util import run_dbt
from dbt.tests.adapter.basic.files import (
    seeds_base_csv,
    generic_test_seed_yml,
    base_view_sql,
    base_table_sql,
    schema_base_yml,
    generic_test_view_yml,
    generic_test_table_yml,
)


class BaseGenericTests:
    @pytest.fixture(scope="class")
    def project_config_update(self):
        return {"name": "generic_tests"}

    @pytest.fixture(scope="class")
    def seeds(self):
        return {
            "base.csv": seeds_base_csv,
            "schema.yml": generic_test_seed_yml,
        }

    @pytest.fixture(scope="class")
    def models(self):
        return {
            "view_model.sql": base_view_sql,
            "table_model.sql": base_table_sql,
            "schema.yml": schema_base_yml,
            "schema_view.yml": generic_test_view_yml,
            "schema_table.yml": generic_test_table_yml,
        }

    def test_generic_tests(self, project):
        # seed command
        results = run_dbt(["seed"])

        # test command selecting base model
        results = run_dbt(["test", "-m", "base"])
        assert len(results) == 1

        # run command
        results = run_dbt(["run"])
        assert len(results) == 2

        # test command, all tests
        results = run_dbt(["test"])
        assert len(results) == 3


class TestGenericTests(BaseGenericTests):
    pass



# escape_single_quotes

models__test_escape_single_quotes_quote_sql = """
select '{{ escape_single_quotes("they're") }}' as actual, 'they''re' as expected union all
select '{{ escape_single_quotes("they are") }}' as actual, 'they are' as expected
"""


# The expected literal is 'they\'re'. The second backslash is to escape it from Python.
models__test_escape_single_quotes_backslash_sql = """
select '{{ escape_single_quotes("they're") }}' as actual, 'they\\'re' as expected union all
select '{{ escape_single_quotes("they are") }}' as actual, 'they are' as expected
"""


models__test_escape_single_quotes_yml = """
version: 2
models:
  - name: test_escape_single_quotes
    tests:
      - assert_equal:
          actual: actual
          expected: expected
"""



import pytest
from dbt.tests.adapter.basic.files import (
    test_passing_sql,
    test_failing_sql,
)
from dbt.tests.util import check_result_nodes_by_name, run_dbt


class BaseSingularTests:
    @pytest.fixture(scope="class")
    def tests(self):
        return {
            "passing.sql": test_passing_sql,
            "failing.sql": test_failing_sql,
        }

    @pytest.fixture(scope="class")
    def project_config_update(self):
        return {"name": "singular_tests"}

    def test_singular_tests(self, project):
        # test command
        results = run_dbt(["test"], expect_pass=False)
        assert len(results) == 2

        # We have the right result nodes
        check_result_nodes_by_name(results, ["passing", "failing"])

        # Check result status
        for result in results:
            if result.node.name == "passing":
                assert result.status == "pass"
            elif result.node.name == "failing":
                assert result.status == "fail"


class TestSingularTests(BaseSingularTests):
    pass



#!/usr/bin/env python
import os
import sys

if sys.version_info < (3, 7):
    print("Error: dbt does not support this version of Python.")
    print("Please upgrade to Python 3.7 or higher.")
    sys.exit(1)


from setuptools import setup

try:
    from setuptools import find_namespace_packages
except ImportError:
    # the user has a downlevel version of setuptools.
    print("Error: dbt requires setuptools v40.1.0 or higher.")
    print('Please upgrade setuptools with "pip install --upgrade setuptools" ' "and try again")
    sys.exit(1)


package_name = "dbt-tests-adapter"
package_version = "1.2.1"
description = """The dbt adapter tests for adapter plugins"""

this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, "README.md")) as f:
    long_description = f.read()

setup(
    name=package_name,
    version=package_version,
    description=description,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="dbt Labs",
    author_email="info@dbtlabs.com",
    url="https://github.com/dbt-labs/dbt-tests-adapter",
    packages=find_namespace_packages(include=["dbt", "dbt.*"]),
    install_requires=[
        "dbt-core=={}".format(package_version),
        "pytest>=7.0.0",
    ],
    zip_safe=False,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    python_requires=">=3.7",
)



# except

seeds__data_except_a_csv = """id
1
2
3
"""

seeds__data_except_b_csv = """id
3
4
5
"""

seeds__data_except_a_minus_b_csv = """id
1
2
"""

seeds__data_except_b_minus_a_csv = """id
4
5
"""

models__data_except_empty_sql = """
select * from {{ ref('data_except_a') }}
where 0=1
"""

models__test_except_a_minus_b_sql = """
select * from {{ ref('data_except_a') }}
{{ except() }}
select * from {{ ref('data_except_b') }}
"""

models__test_except_b_minus_a_sql = """
select * from {{ ref('data_except_b') }}
{{ except() }}
select * from {{ ref('data_except_a') }}
"""

models__test_except_a_minus_a_sql = """
select * from {{ ref('data_except_a') }}
{{ except() }}
select * from {{ ref('data_except_a') }}
"""

models__test_except_a_minus_empty_sql = """
select * from {{ ref('data_except_a') }}
{{ except() }}
select * from {{ ref('data_except_empty') }}
"""

models__test_except_empty_minus_a_sql = """
select * from {{ ref('data_except_empty') }}
{{ except() }}
select * from {{ ref('data_except_a') }}
"""

models__test_except_empty_minus_empty_sql = """
select * from {{ ref('data_except_empty') }}
{{ except() }}
select * from {{ ref('data_except_empty') }}
"""
